@@ -1,5 +1,7 @@
 # Some aliases similar to matplotlib.cm
-Blues = "Blues"
+BkRd = "BkRd"
+BkGn = "BkGn"
+BkBu = "BkBu"
 BkCy = "BkCy"
 BkMa = "BkMa"
 BrBG = "BrBG"
@@ -15,7 +17,6 @@ GnBuPu = "GnBuPu"
 GnRP = "GnRP"
 GnYlRd = "GnYlRd"
 grayscale = "Grayscale"
-Greens = "Greens"
 GyRd = "GyRd"
 Haze = "Haze"
 inferno = "Inferno (matplotlib)"
@@ -32,7 +33,6 @@ Purples = "Purples"
 RdOr = "RdOr"
 RdOrYl = "RdOrYl"
 RdPu = "RdPu"
-Reds = "Reds"
 viridis = "Viridis (matplotlib)"
 xray = "X Ray"
 blot = "blot"
