@@ -71,35 +71,35 @@ def _image_to_type(itkimage):  # noqa: C901
     if component in (itk.SC, itk.UC, itk.SS, itk.US, itk.SI, itk.UI, itk.F,
             itk.D, itk.B):
         mangle = component
-    elif component in itk.Vector.iteritems():
+    elif component in [i[1] for i in itk.Vector.iteritems()]:
         mangle = itk.template(component)[1][0]
         pixelType = 5
-    elif component == itk.CF:
+    elif component == itk.complex[itk.F]:
         # complex float
         return 'float', 10
-    elif component == itk.CD:
+    elif component == itk.complex[itk.D]:
         # complex float
         return 'double', 10
-    elif component in itk.CovariantVector.iteritems():
+    elif component in [i[1] for i in itk.CovariantVector.iteritems()]:
         # CovariantVector
         mangle = itk.template(component)[1][0]
         pixelType = 7
-    elif component in itk.Offset.iteritems():
+    elif component in [i[1] for i in itk.Offset.iteritems()]:
         # Offset
         return 'int64_t', 4
-    elif component in itk.FixedArray.iteritems():
+    elif component in [i[1] for i in itk.FixedArray.iteritems()]:
         # FixedArray
         mangle = itk.template(component)[1][0]
         pixelType = 11
-    elif component in itk.RGBAPixel.iteritems():
+    elif component in [i[1] for i in itk.RGBAPixel.iteritems()]:
         # RGBA
         mangle = itk.template(component)[1][0]
         pixelType = 3
-    elif component in itk.RGBPixel.iteritems():
+    elif component in [i[1] for i in itk.RGBPixel.iteritems()]:
         # RGB
         mangle = itk.template(component)[1][0]
         pixelType = 2
-    elif component in itk.SymmetricSecondRankTensor.iteritems():
+    elif component in [i[1] for i in itk.SymmetricSecondRankTensor.iteritems()]:
         # SymmetricSecondRankTensor
         mangle = itk.template(component)[1][0]
         pixelType = 8
@@ -603,8 +603,8 @@ class Colormap(traitlets.Unicode):
                          'Magma (matplotlib)',
                          'Grayscale',
                          'X Ray',
-                         'magenta',
-                         'blue2cyan',
+                         'BkMa',
+                         'BkCy',
                          'gray_Matlab',
                          'bone_Matlab',
                          'pink_Matlab',
@@ -639,9 +639,9 @@ class Colormap(traitlets.Unicode):
                          'Green-Blue Asymmetric Divergent (62Blbc)',
                          'Muted Blue-Green',
 
-                         'Reds',
-                         'Greens',
-                         'Blues',
+                         'BkRd',
+                         'BkGn',
+                         'BkBu',
                          'Purples',
                          'Oranges',
                          'PuBu',
@@ -662,7 +662,9 @@ class Colormap(traitlets.Unicode):
                          )
 
     def validate(self, obj, value):
-        if isinstance(value, np.ndarray):
+        if value is None:
+            return None
+        elif isinstance(value, np.ndarray):
             custom_cmap = value.astype(np.float32)
             custom_cmap = custom_cmap[:, :3]
             obj._custom_cmap = custom_cmap
@@ -678,3 +680,38 @@ class Colormap(traitlets.Unicode):
                 'Custom'):
             raise self.error('Invalid colormap')
         return super(Colormap, self).validate(obj, value)
+
+class LookupTable(traitlets.Unicode):
+    """A trait type holding a lookup table."""
+
+    info_text = 'A lookup table, either a itk-vtk-viewer categorical colormap preset, todo: np.ndarray of RGB points, or matplotlib ListedColormap.'
+
+    _lookup_table_presets = ('glasbey',
+                             'glasbey_light',
+                             'glasbey_warm',
+                             'modulate',
+                             'glasbey_bw',
+                             'glasbey_dark',
+                             'glasbey_cool',
+                             'modulate_dark',
+                             )
+
+    def validate(self, obj, value):
+        if value is None:
+            return None
+        # elif isinstance(value, np.ndarray):
+            # custom_cmap = value.astype(np.float32)
+            # custom_cmap = custom_cmap[:, :3]
+            # obj._custom_cmap = custom_cmap
+            # timestamp = str(datetime.timestamp(datetime.now()))
+            # return 'Custom NumPy ' + timestamp
+        # elif isinstance(value, matplotlib.colors.ListedColormap):
+            # custom_cmap = value(np.linspace(0.0, 1.0, 64)).astype(np.float32)
+            # custom_cmap = custom_cmap[:, :3]
+            # obj._custom_cmap = custom_cmap
+            # timestamp = str(datetime.timestamp(datetime.now()))
+            # return 'Custom matplotlib ' + timestamp
+        if value not in self._lookup_table_presets and not value.startswith(
+                'Custom'):
+            raise self.error('Invalid lookup table')
+        return super(LookupTable, self).validate(obj, value)
